(**
  * JSON Data Structures
  * Copyright (C) 2002 Rafael R. Sevilla <dido@imperium.ph>
  * This file is part of JSON for Ocaml
  *
  * JSON for OCaml is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * JSON for OCaml is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details. 
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with JSON for OCaml; if not, write to the Free
  * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA.
  * $Id: json.mli,v 1.5 2003/08/20 10:21:30 didosevilla Exp $
  * @author Rafael R. Sevilla <dido@imperium.ph>
  *)

(** This is the basic type declaration for JSON types. A [jsontype] is
  * either a boolean, an integer, a floating point value, a string, a
  * hashtable mapping strings to a [jsontype] (JSON objects) or an
  * array of other [jsontype]s.
  *)
type jsontype =
    Bool of bool
  | Int of int
  | Float of float
  | String of string
  | Object of (string, jsontype) Hashtbl.t
  | Array of jsontype array
  | Null

exception Eof

val serialize : jsontype -> string
val deserialize : string -> jsontype
